@@ -38,14 +38,16 @@ something.
 
 use strict;
 use warnings;
-use OpenGL     ();
-use SDL::Image ();
-use SDL::Video ();
+use SDL::Image                     ();
+use SDL::Video                     ();
+use SDL::Tutorial::3DWorld::OpenGL ();
 
-# Ensure all the OpenGL "constants" are loaded
-use SDL::Tutorial::3DWorld ();
+# SDL::Image creates SDL::Surface objects without loading their classes.
+# Naughty, naughty, naughty!
+use SDL::Surface     ();
+use SDL::PixelFormat ();
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 =pod
 
@@ -111,9 +113,9 @@ sub init {
 
 	# Use SDL to load the image
 	my $image = SDL::Image::load( $self->file );
-
-	# Check if the image actually got loaded
-	Carp::croak( 'Cannot load image at '.$self->file. ": ".SDL::get_error) unless $image;
+	unless ( $image ) {
+		die "Cannot load image file '" . $self->file . "'";
+	}
 
 	# Tell SDL to leave the memory the image is in exactly where
 	# it is, so that OpenGL can bind to it directly.
